==> spip_4.1.13+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_fi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=fi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_site_introuvable' => 'Sivusto ei löytynyt',
	'avis_site_syndique_probleme' => 'Attention : la syndication de ce site a rencontré un problème ; le système est donc temporairement interrompu pour l’instant. Vérifiez l’adresse du fichier de syndication de ce site (<b>@url_syndic@</b>), et tentez une nouvelle récupération des informations.', # MODIF
	'avis_sites_probleme_syndication' => 'Näillä sivustoilla oli syndikoinnnissa ongelmia',
	'avis_sites_syndiques_probleme' => 'Nämä syndikoidut sivustot tuottivat ongelman',

	// B
	'bouton_radio_modere_posteriori' => 'moderointi jälkikäteen', # MODIF
	'bouton_radio_modere_priori' => 'moderointi etukäteen', # MODIF
	'bouton_radio_non_syndication' => 'Ei syndikointia',
	'bouton_radio_syndication' => 'Syndikointi:',

	// E
	'entree_adresse_fichier_syndication' => '«backend» -tiedoston osoite syndikointia varten:', # MODIF
	'entree_adresse_site' => '<b>Sivusto URL-osoite</b> [Pakollinen]',
	'entree_description_site' => 'Sivuston kuvaus',

	// F
	'form_prop_nom_site' => 'Sivuston nimi',

	// I
	'info_1_site' => '1 sivusto',
	'info_a_valider' => '[varmennettava]',
	'info_bloquer_lien' => 'estä tämä linkki',
	'info_nom_site_2' => '<b>Sivuston nimi</b> [Pakollinen]',
	'info_panne_site_syndique' => 'Syndikoitu sivusto ei ole toiminnassa',
	'info_retablir_lien' => 'palauta tämä linkki',
	'info_site_attente' => 'Sivusto odottaa varmennusta',
	'info_site_propose' => 'Sivusto lähetetty:',
	'info_site_reference' => 'Viittaavaa sivustoa linjoilla',
	'info_site_refuse' => 'Sivusto hylätty',
	'info_site_syndique' => 'Tämä sivusto on syndikoitu...', # MODIF
	'info_site_valider' => 'Hyväksyttävät sivustot',
	'info_sites_referencer' => 'Lainata sivustoa',
	'info_sites_refuses' => 'Hylätyt sivustot',
	'info_statut_site_1' => 'Tämä sivusto on:',
	'info_statut_site_2' => 'Julkaistu',
	'info_statut_site_3' => 'Lähetetty',
	'info_statut_site_4' => 'Roskakorissa', # MODIF
	'info_syndication' => 'syndikointi:', # MODIF
	'info_syndication_articles' => 'artkkeli(t)',

	// T
	'texte_syndication' => 'Il est possible de récupérer automatiquement, lorsqu’un site Web le permet, 
		la liste de ses nouveautés. Pour cela, vous devez activer la syndication. 
		<blockquote><i>Certains hébergeurs désactivent cette fonctionnalité ; 
		dans ce cas, vous ne pourrez pas utiliser la syndication de contenu
		depuis votre site.</i></blockquote>', # MODIF
	'titre_dernier_article_syndique' => 'Viimeisimmät syndikoidut artikkelit',
	'titre_page_sites_tous' => 'Lähdesivustot',
	'titre_referencement_sites' => 'Sivustojen lainaukset ja syndikoinnit',
	'titre_site_numero' => 'SIVUSTO NUMERO:',
	'titre_sites_proposes' => 'Lähetetyt sivustot',
	'titre_sites_references_rubrique' => 'Viitatut sivustot tässä lohkossa',
	'titre_sites_syndiques' => 'Syndikoidut sivustot',
	'titre_sites_tous' => 'Viitatut sivustot'
);

==> spip_4.4.10+dfsg.orig.tar.xz: plugins-dist/sites/lang/sites_fi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/sites?lang_cible=fi
// ** ne pas modifier le fichier **

return [

	// A
	'avis_site_introuvable' => 'Sivusto ei löytynyt',
	'avis_site_syndique_probleme' => 'Attention : la syndication de ce site a rencontré un problème ; le système est donc temporairement interrompu pour l’instant. Vérifiez l’adresse du fichier de syndication de ce site (<b>@url_syndic@</b>), et tentez une nouvelle récupération des informations.', # MODIF
	'avis_sites_probleme_syndication' => 'Näillä sivustoilla oli syndikoinnnissa ongelmia',
	'avis_sites_syndiques_probleme' => 'Nämä syndikoidut sivustot tuottivat ongelman',

	// B
	'bouton_radio_modere_posteriori' => 'moderointi jälkikäteen', # MODIF
	'bouton_radio_modere_priori' => 'moderointi etukäteen', # MODIF
	'bouton_radio_non_syndication' => 'Ei syndikointia',
	'bouton_radio_syndication' => 'Syndikointi:',

	// E
	'entree_adresse_fichier_syndication' => '«backend» -tiedoston osoite syndikointia varten:', # MODIF
	'entree_adresse_site' => '<b>Sivusto URL-osoite</b> [Pakollinen]',
	'entree_description_site' => 'Sivuston kuvaus',

	// F
	'form_prop_nom_site' => 'Sivuston nimi',

	// I
	'info_1_site' => '1 sivusto',
	'info_a_valider' => '[varmennettava]',
	'info_bloquer_lien' => 'estä tämä linkki',
	'info_nom_site_2' => '<b>Sivuston nimi</b> [Pakollinen]',
	'info_panne_site_syndique' => 'Syndikoitu sivusto ei ole toiminnassa',
	'info_retablir_lien' => 'palauta tämä linkki',
	'info_site_attente' => 'Sivusto odottaa varmennusta',
	'info_site_propose' => 'Sivusto lähetetty:',
	'info_site_reference' => 'Viittaavaa sivustoa linjoilla',
	'info_site_refuse' => 'Sivusto hylätty',
	'info_site_syndique' => 'Tämä sivusto on syndikoitu...', # MODIF
	'info_site_valider' => 'Hyväksyttävät sivustot',
	'info_sites_referencer' => 'Lainata sivustoa',
	'info_sites_refuses' => 'Hylätyt sivustot',
	'info_statut_site_1' => 'Tämä sivusto on:',
	'info_statut_site_2' => 'Julkaistu',
	'info_statut_site_3' => 'Lähetetty',
	'info_statut_site_4' => 'Roskakorissa', # MODIF
	'info_syndication' => 'syndikointi:', # MODIF
	'info_syndication_articles' => 'artkkeli(t)',

	// T
	'texte_syndication' => 'Il est possible de récupérer automatiquement, lorsqu’un site Web le permet, 
		la liste de ses nouveautés. Pour cela, vous devez activer la syndication. 
		<blockquote><i>Certains hébergeurs désactivent cette fonctionnalité ; 
		dans ce cas, vous ne pourrez pas utiliser la syndication de contenu
		depuis votre site.</i></blockquote>', # MODIF
	'titre_dernier_article_syndique' => 'Viimeisimmät syndikoidut artikkelit',
	'titre_page_sites_tous' => 'Lähdesivustot',
	'titre_referencement_sites' => 'Sivustojen lainaukset ja syndikoinnit',
	'titre_site_numero' => 'SIVUSTO NUMERO:',
	'titre_sites_proposes' => 'Lähetetyt sivustot',
	'titre_sites_references_rubrique' => 'Viitatut sivustot tässä lohkossa',
	'titre_sites_syndiques' => 'Syndikoidut sivustot',
	'titre_sites_tous' => 'Viitatut sivustot',
];
